summaryrefslogtreecommitdiffstats
path: root/core/java/android/content/Intent.java
diff options
context:
space:
mode:
authorMakoto Onuki <omakoto@google.com>2015-06-05 16:27:23 -0700
committerMakoto Onuki <omakoto@google.com>2015-06-08 17:51:14 -0700
commitbbb912a89e92b389c7f9f4f7669a6b2836cb159a (patch)
treef109e4cda4182b7ddbe8d1b1fab4f797bd92acc0 /core/java/android/content/Intent.java
parent0e0942d55d62e820ecdc2c7ec25b02fca169fa79 (diff)
downloadframeworks_base-bbb912a89e92b389c7f9f4f7669a6b2836cb159a.zip
frameworks_base-bbb912a89e92b389c7f9f4f7669a6b2836cb159a.tar.gz
frameworks_base-bbb912a89e92b389c7f9f4f7669a6b2836cb159a.tar.bz2
Add more result extras for ACTION_GET_PERMISSIONS_COUNT
Now ACTION_GET_PERMISSIONS_COUNT returns more than counts, its a misnomer, but I don't think it's worth renaming it, as Svet is planning to change the interface to a service. Bug 21615746 Change-Id: I9ce1f3ed674b21bb56ee5a8e2baed0017f5ae81a
Diffstat (limited to 'core/java/android/content/Intent.java')
-rw-r--r--core/java/android/content/Intent.java23
1 files changed, 17 insertions, 6 deletions
diff --git a/core/java/android/content/Intent.java b/core/java/android/content/Intent.java
index 5c23204..2b10e5a 100644
--- a/core/java/android/content/Intent.java
+++ b/core/java/android/content/Intent.java
@@ -1575,13 +1575,17 @@ public class Intent implements Parcelable, Cloneable {
* Broadcast action that requests current permission granted information. It will respond
* to the request by sending a broadcast with action defined by
* {@link #EXTRA_GET_PERMISSIONS_RESPONSE_INTENT}. The response will contain
* {@link #EXTRA_GET_PERMISSIONS_COUNT_RESULT} with contents described below or a null upon
* failure.
*
- * <p>If {@link #EXTRA_PACKAGE_NAME} is included then the number of permissions granted and the
- * number of permissions requested by that package will be calculated and included as the first
+ * <p>If {@link #EXTRA_PACKAGE_NAME} is included then the number of permissions granted, the
+ * number of permissions requested and the number of granted additional permissions
+ * by that package will be calculated and included as the first
* and second elements respectively of an int[] in the response as
- * {@link #EXTRA_GET_PERMISSIONS_COUNT_RESULT}.
+ * {@link #EXTRA_GET_PERMISSIONS_COUNT_RESULT}. The response will also deliver the list
+ * of localized permission group names that are granted in
+ * {@link #EXTRA_GET_PERMISSIONS_GROUP_LIST_RESULT}.
*
* <p>If {@link #EXTRA_PACKAGE_NAME} is not included then the number of apps granted any runtime
* permissions and the total number of apps requesting runtime permissions will be the first
@@ -1601,7 +1605,14 @@ public class Intent implements Parcelable, Cloneable {
= "android.intent.extra.GET_PERMISSIONS_COUNT_RESULT";
/**
- * Required extra to be sent with {@link #ACTION_GET_PERMISSIONS_COUNT} broadcast.
+ * List of CharSequence of localized permission group labels.
+ * @hide
+ */
+ public static final String EXTRA_GET_PERMISSIONS_GROUP_LIST_RESULT
+ = "android.intent.extra.GET_PERMISSIONS_GROUP_LIST_RESULT";
+
+ /**
+ * Required extra to be sent with {@link #ACTION_GET_PERMISSIONS_COUNT} broadcasts.
* @hide
*/
public static final String EXTRA_GET_PERMISSIONS_RESPONSE_INTENT
@@ -1575,13 +1575,17 @@ public class Intent implements Parcelable, Cloneable {
* to the request by sending a broadcast with action defined by
* {@link #EXTRA_GET_PERMISSIONS_RESPONSE_INTENT}. The response will contain
- * {@link #EXTRA_GET_PERMISSIONS_COUNT_RESULT} with contents described below or a null upon
- * failure.
+ * {@link #EXTRA_GET_PERMISSIONS_COUNT_RESULT}, as well as
+ * {@link #EXTRA_GET_PERMISSIONS_GROUP_LIST_RESULT}, with contents described below or
+ * a null upon failure.
*